@@ -168,15 +168,21 @@ class Error(OSError):
 
 class DuPanClient:
 
-    def __init__(self, cookie: Optional[str] = None):
+    def __init__(self, cookie: Optional[str] = None, scan_in_console: bool = True):
         session = self.session = Session()
         session.headers["User-Agent"] = "pan.baidu.com"
-        if not cookie or "BDUSS=" not in cookie:
-            self.login_with_qrcode()
-            self.request("https://pan.baidu.com/disk/main")
-        else:
-            self.cookie = cookie
-        resp = Error.check(self.get_gettemplatevariable("bdstoken"))
+        for _ in range(2):
+            if not cookie or "BDUSS=" not in cookie:
+                self.login_with_qrcode(scan_in_console=scan_in_console)
+                self.request("https://pan.baidu.com/disk/main")
+                resp = Error.check(self.get_gettemplatevariable("bdstoken"))
+                break
+            else:
+                self.cookie = cookie
+                try:
+                    resp = Error.check(self.get_gettemplatevariable("bdstoken"))
+                except:
+                    cookie = None
         self.bdstoken = resp["result"]["bdstoken"]
         #self.logid = b64encode(self.session.cookies["BAIDUID"].encode("ascii")).decode("ascii")
 
@@ -381,6 +387,20 @@ class DuPanClient:
         /, 
         payload: list | tuple | dict, 
     ) -> dict:
+        """复制
+        payload:
+            {
+                filelist: [
+                    {
+                        "path": str,      # 源文件路径
+                        "newname": str,   # 目标文件名
+                        "dest": str = "", # 目标目录
+                        "ondup": "" | "newcopy" | "overwrite" = "", # 文件存在时 1. "": 忽略 2. "newcopy": 生成副本 3. "overwrite": 覆盖文件
+                    }, 
+                    ...
+                ]
+            }
+        """
         return self.filemanager("copy", payload)
 
     def delete(
@@ -388,6 +408,15 @@ class DuPanClient:
         /, 
         payload: str | list | tuple | dict, 
     ) -> dict:
+        """删除
+        payload:
+            {
+                filelist: [
+                    str, # 文件路径
+                    ...
+                ]
+            }
+        """
         return self.filemanager("delete", payload)
 
     def move(
@@ -395,6 +424,20 @@ class DuPanClient:
         /, 
         payload: list | tuple | dict, 
     ) -> dict:
+        """移动
+        payload:
+            {
+                filelist: [
+                    {
+                        "path": str,      # 源文件路径
+                        "newname": str,   # 目标文件名
+                        "dest": str = "", # 目标目录
+                        "ondup": "" | "newcopy" | "overwrite" = "", # 文件存在时 1. "": 忽略 2. "newcopy": 生成副本 3. "overwrite": 覆盖文件
+                    }, 
+                    ...
+                ]
+            }
+        """
         return self.filemanager("move", payload)
 
     def rename(
@@ -402,6 +445,19 @@ class DuPanClient:
         /, 
         payload: list | tuple | dict, 
     ) -> dict:
+        """重命名
+        payload:
+            {
+                filelist: [
+                    {
+                        "id": int,      # 文件 id
+                        "path": str,    # 源文件路径
+                        "newname": str, # 目标文件名
+                    }, 
+                    ...
+                ]
+            }
+        """
         return self.filemanager("rename", payload)
 
     def taskquery(
@@ -409,6 +465,12 @@ class DuPanClient:
         /, 
         payload: int | str | dict, 
     ) -> dict:
+        """任务进度查询
+        status: "pending"
+        status: "running"
+        status: "failed"
+        status: "success"
+        """
         api = "https://pan.baidu.com/share/taskquery"
         if isinstance(payload, (int, str)):
             payload = {"clienttype": 0, "web": 1, "taskid": payload}
